try:
    from webkit import WebView, WebSettings
except ImportError:
    print "webkit not found"

try:
    from PyQt4.QtWebKit import QWebView
    from PyQt4.QtCore import *
    from PyQt4.QtGui import *
except:
    print "webkit QT not found"

class WebKitMethods(object):
    @staticmethod
    def create_browser():
        settings = WebSettings()
        #settings.set_property('enable-xss-auditor', False)
        # todas las settings en http://webkitgtk.org/reference/webkitgtk/stable/WebKitWebSettings.html
        settings.set_property('enable-default-context-menu', False)
        settings.set_property('enable-accelerated-compositing', True)
        settings.set_property('enable-file-access-from-file-uris', True)
        webview = WebView()
        webview.set_settings(settings)
        return webview

    @staticmethod
    def inject_javascript(browser, script):
        browser.execute_script(script)

    @staticmethod
    def open_uri(browser, uri):
        browser.open(uri)

    @staticmethod
    def set_settings(browser, user_settings):
        browser_settings = browser.get_settings()
        if user_settings is not None:
            for setting, value in user_settings:
                browser_settings.set_property(setting, value)

class QTWebKitMethods(object):
    @staticmethod
    def create_browser():
        web = QWebView()
        return web

    @staticmethod
    def inject_javascript(browser, script):
        browser.execute_script(script)

    @staticmethod
    def open_uri(browser, uri):
        browser.load(QUrl(uri))

    @staticmethod
    def set_settings(browser, user_settings):
        pass



class BaseActionController(object):
    """Base class for actions that are binded into controllers."""

    def __init__(self, controller):
        self.__controller = controller

    @property
    def controller(self):
        """Returns the controller instance."""
        return self.__controller



import gobject

from zaguan.constants import WEBKIT

def get_implementation():
    try:
        import webkit
        have_webkit = True
    except:
        have_webkit = False

    if have_webkit:
        implementation = WEBKIT
    else:
        raise Exception('Failed to import webkit module')
    return implementation

def asynchronous_gtk_message(fun):
    def worker((function, args, kwargs)):
        apply(function, args, kwargs)

    def fun2(*args, **kwargs):
        gobject.idle_add(worker, (fun, args, kwargs))

    return fun2



try:
    import gtk
except ImportError:
    print  "no tiene GTK instalado"
try:
    import sys
    from PyQt4.QtCore import *
    from PyQt4.QtGui import *
except ImportError:
    print "no tiene QT instalado"

from time import sleep

from zaguan.controller import WebContainerController
from zaguan.inspector import Inspector


class Zaguan(object):
    def __init__(self, uri, controller=None):
        if controller is None:
            controller = WebContainerController()
        self.controller = controller
        self.uri = uri
        self.on_close = None

    def run(self, settings=None, window=None, debug=False,
            qt=False, on_close=None):
        self.on_close = on_close

        if qt:
            self.run_qt(settings, window, debug)
        else:
            self.run_gtk(settings, window, debug)

    def run_gtk(self, settings=None, window=None, debug=False):
        gtk.gdk.threads_init()

        if window is None:
            self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
            self.window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
        else:
            self.window = window

        if debug:
            settings.append(('enable-default-context-menu', True))
            settings.append(('enable-developer-extras', True))

        browser = self.controller.get_browser(self.uri, debug=debug,
                                              settings=settings)
        self.window.connect("delete-event", self.quit)
        self.window.set_border_width(0)
        self.window.add(browser)
        if debug:
            inspector = browser.get_web_inspector()
            Inspector(inspector)

        sleep(1)
        self.window.show_all()
        self.window.show()
        gtk.main()

    def run_qt(self, settings, window, debug):
        if window is None:
            self.window = QApplication(sys.argv)
        else:
            self.window = window

        browser = self.controller.get_browser(self.uri, debug=debug,
                                              settings=settings, qt=True)
        browser.show()
        sys.exit(self.window.exec_())

    def quit(self, widget, event):
        if self.on_close is not None:
            self.on_close(widget, event)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

setup(
    name='zaguan',
    version='1.1.1',
    author='Felipe Lerena',
    author_email='flerena@msa.com.ar',
    packages=['zaguan'],
    scripts=[],
    url='http://pypi.python.org/pypi/zaguan/',
    license='LICENSE.txt',
    description='Front end framework to develop apps with webkit an pygtk',
    long_description=open('README.txt').read(),
    install_requires=[],
)
